@@ -8,6 +8,7 @@ from io import BytesIO
 
 from PIL import Image  # type: ignore
 
+from examples.utils import pretty_print
 from kentik_api import (
     Aggregate,
     AggregateFunctionType,
@@ -35,8 +36,18 @@ def run_query_data() -> None:
     email, token = get_credentials()
     client = KentikAPI(email, token)
 
-    agg1 = Aggregate(name="avg_bits_per_sec", column="f_sum_both_bytes", fn=AggregateFunctionType.average, raw=True)
-    agg2 = Aggregate(name="p95th_bits_per_sec", column="f_sum_both_bytes", fn=AggregateFunctionType.percentile, rank=95)
+    agg1 = Aggregate(
+        name="avg_bits_per_sec",
+        column="f_sum_both_bytes",
+        fn=AggregateFunctionType.average,
+        raw=True,
+    )
+    agg2 = Aggregate(
+        name="p95th_bits_per_sec",
+        column="f_sum_both_bytes",
+        fn=AggregateFunctionType.percentile,
+        rank=95,
+    )
     agg3 = Aggregate(name="max_bits_per_sec", column="f_sum_both_bytes", fn=AggregateFunctionType.max)
     query = Query(
         dimension=[DimensionType.Traffic],
@@ -61,8 +72,8 @@ def run_query_data() -> None:
     result = client.query.data(query_object)
 
     print("Results:")
-    for item in result.results:
-        print(item)
+    pretty_print(result.results)
+    print()
 
 
 def run_query_chart() -> None:
@@ -73,8 +84,18 @@ def run_query_chart() -> None:
     email, token = get_credentials()
     client = KentikAPI(email, token)
 
-    agg1 = Aggregate(name="avg_bits_per_sec", column="f_sum_both_bytes", fn=AggregateFunctionType.average, raw=True)
-    agg2 = Aggregate(name="p95th_bits_per_sec", column="f_sum_both_bytes", fn=AggregateFunctionType.percentile, rank=95)
+    agg1 = Aggregate(
+        name="avg_bits_per_sec",
+        column="f_sum_both_bytes",
+        fn=AggregateFunctionType.average,
+        raw=True,
+    )
+    agg2 = Aggregate(
+        name="p95th_bits_per_sec",
+        column="f_sum_both_bytes",
+        fn=AggregateFunctionType.percentile,
+        rank=95,
+    )
     agg3 = Aggregate(name="max_bits_per_sec", column="f_sum_both_bytes", fn=AggregateFunctionType.max)
     query = Query(
         dimension=[DimensionType.Traffic],
@@ -139,7 +160,8 @@ def run_query_url() -> None:
     result = client.query.url(query_object)
 
     print("Result:")
-    print(result)
+    pretty_print(result)
+    print()
 
 
 def run_query_sql() -> None:
@@ -171,7 +193,8 @@ def run_query_sql() -> None:
     result = client.query.sql(sql_query)
 
     print("Result:")
-    print(result.rows)
+    pretty_print(result.rows)
+    print()
 
 
 if __name__ == "__main__":
