@@ -1,5 +1,6 @@
 from typing import Optional
 
+from kentik_api.public.errors import IncompleteObjectError
 from kentik_api.public.types import ID
 
 
@@ -26,7 +27,8 @@ class Site:
 
     @property
     def id(self) -> ID:
-        assert self._id is not None
+        if self._id is None:
+            raise IncompleteObjectError("", self.__class__.__name__, "_id is required")
         return self._id
 
     @property
