@@ -1,3 +1,3 @@
-from .auth import get_credentials
+from .auth import get_credentials, get_proxy, get_url
 from .device_cache import DeviceCache
 from .time_sequence import time_seq
