@@ -1,6 +1,5 @@
-from kentik_api.api_calls.api_call import APICall
-from kentik_api.api_calls.api_call import APICallMethods
 from kentik_api.api_calls.active_alerts import *
+from kentik_api.api_calls.api_call import APICall, APICallMethods
 
 DUMMY_API_URL = "/alerts-active"
 
